==> ejc-lz-impl-3.0.0-20220509.024412-92-sources.jar: com/ejianc/business/base/excel/ExcelShipperLinkerController.java <==
package com.ejianc.business.base.excel;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.base.bean.ShippersEntity;
import com.ejianc.business.base.bean.ShippersLinkerEntity;
import com.ejianc.business.base.bean.SupplierinfoEntity;
import com.ejianc.business.base.bean.SupplierlinkerEntity;
import com.ejianc.business.base.service.IShippersLinkerService;
import com.ejianc.business.base.service.IShippersService;
import com.ejianc.business.base.service.ISupplierbankService;
import com.ejianc.business.base.service.ISupplierinfoService;
import com.ejianc.business.base.vo.ShippersLinkerVO;
import com.ejianc.business.base.vo.SupplierbankVO;
import com.ejianc.business.base.vo.SupplierlinkerVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.ExcelReader;
import com.ejianc.framework.core.util.FileUtils;
import com.ejianc.framework.core.util.ImportTemplate;
import com.ejianc.support.idworker.util.IdWorker;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.*;

/**
 * 运输商联系人导入
 */
@Controller
@RequestMapping("shipperLinkerExport")
public class ExcelShipperLinkerController implements Serializable {
    private static final long serialVersionUID = 1L;
    @Autowired
    private IShippersLinkerService service;
    @Autowired
    private IShippersService shippersService;
    @Autowired
    private IBillCodeApi billCodeApi;

    private static final String BILL_CODE = "shippers-linker";//此处需要根据实际修改
    /**
     * 导入模板下载
     *
     * @param request
     * @param response
     */
    @RequestMapping(value = "/downloadShipperLinker")
    @ResponseBody
    public void downloadSupplybank(HttpServletRequest request, HttpServletResponse response) {
        ImportTemplate.initialize(response);
        ImportTemplate.templetdownload(request, "shipperlinker-import.xlsx", "客户银行信息导入模板");
    }
    /**
     * excel导入
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/excelImportShipperlinker", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<Object> excelImportShipperlinker(HttpServletRequest request, HttpServletResponse response){
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        List<ShippersLinkerVO> successList = new ArrayList<>();
        List<ShippersLinkerVO> errorList = new ArrayList<>();
        HashMap<String, String> map = new HashMap<>();
        boolean isFailed = false;
        MultipartFile mf = null;
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            mf = entity.getValue();
            String originalFileName = mf.getOriginalFilename();
            String extName = null;
            originalFileName = originalFileName.replaceAll("\\/|\\/|\\||:|\\?|\\*|\"|<|>|\\p{Cntrl}", "_");
            originalFileName.replaceAll("00.", "");
            extName = FileUtils.getFileExt(originalFileName, false);
            if (!"xls".equals(extName) && !"xlsx".equals(extName)) {
                isFailed = true;
                break;
            }
        }
        if (isFailed) {
            return CommonResponse.error("文件格式不合法");
        } else {
            List<List<String>> result = ExcelReader.readExcel(mf);
            if ( result.size() > 0) {
                for (int i = 1; i < result.size(); i++) {
                    List<String> data = result.get(i);
                    ShippersLinkerVO VO =new ShippersLinkerVO();
                    VO.setId(IdWorker.getId());
                    VO.setName(StringUtils.isNotBlank(data.get(0)) ? data.get(0) : null);
                    VO.setShipperManageName(StringUtils.isNotBlank(data.get(1)) ? data.get(1) : null);
                    VO.setLinkerName(StringUtils.isNotBlank(data.get(2)) ? data.get(2) : null);
                    VO.setLinkerPhone(StringUtils.isNotBlank(data.get(3)) ? data.get(3) : null);
                    VO.setTenantId(InvocationInfoProxy.getTenantid());
                    VO.setOrgId(InvocationInfoProxy.getOrgId());
                    VO.setCreateUserCode(InvocationInfoProxy.getUsercode());
                    VO.setCreateTime(new Date());
                    if (StringUtils.isEmpty(data.get(0)) || data.get(0) == null) {
                        VO.setErrorMsg("'运输商联系人名称'不能为空！");
                        errorList.add(VO);
                        continue;
                    }
                    if (StringUtils.isEmpty(data.get(1)) || data.get(1) == null) {
                        VO.setErrorMsg("'运输商名称'不能为空！");
                        errorList.add(VO);
                        continue;
                    }else{
                        QueryWrapper query=new QueryWrapper();
                        query.eq("name",data.get(1));
                        query.eq("org_id",InvocationInfoProxy.getOrgId());
                        ShippersEntity entity = shippersService.getOne(query);
                        if (entity!=null&&(entity.getId()!=null|| entity.getId() != 0)){
                            VO.setShipperMid(entity.getId());
                        }else {
                            VO.setErrorMsg("运输商名称库未查找到运输商名称，请检查！");
                            errorList.add(VO);
                            continue;
                        }
                    }
                    if (StringUtils.isEmpty(data.get(2)) || data.get(2) == null) {
                        VO.setErrorMsg("'联系人名称'不能为空！");
                        errorList.add(VO);
                        continue;
                    }
                    if (StringUtils.isEmpty(data.get(3)) || data.get(3) == null) {
                        VO.setErrorMsg("'手机号'不能为空！");
                        errorList.add(VO);
                        continue;
                    }else {
                        QueryWrapper query=new QueryWrapper();
                        query.eq("linker_phone",data.get(3));
                        query.eq("org_id",InvocationInfoProxy.getOrgId());
                        ShippersLinkerEntity entity = service.getOne(query);
                        if (entity!=null&&(entity.getId()!=null|| entity.getId() != 0)){
                            VO.setErrorMsg("查重校验:'手机号'已存在，请检查！");
                            errorList.add(VO);
                            continue;
                        }
                    }
                    successList.add(VO);
                }
                if (errorList.size()==0) {
                    List<ShippersLinkerEntity> shippersLinkerEntities = BeanMapper.mapList(successList, ShippersLinkerEntity.class);
                    for (ShippersLinkerEntity entity : shippersLinkerEntities) {
                        ShippersLinkerVO VO = BeanMapper.map(entity, ShippersLinkerVO.class);
                        BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(),VO);
                        CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
                        if(billCode.isSuccess()) {
                            entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                        }
                    }
                    service.saveBatch(shippersLinkerEntities, successList.size());
                }
            }
        }
        JSONObject json = new JSONObject();
        json.put("successNum", successList.size());
        json.put("successList", successList);
        json.put("errorList", errorList);
        json.put("errorNum", errorList.size());
        return CommonResponse.success(json);
    }
}

==> ejc-lz-impl-3.0.0-20220526.021003-106-sources.jar: com/ejianc/business/base/excel/ExcelShipperLinkerController.java <==
package com.ejianc.business.base.excel;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.base.bean.ShippersEntity;
import com.ejianc.business.base.bean.ShippersLinkerEntity;
import com.ejianc.business.base.bean.SupplierinfoEntity;
import com.ejianc.business.base.bean.SupplierlinkerEntity;
import com.ejianc.business.base.service.IShippersLinkerService;
import com.ejianc.business.base.service.IShippersService;
import com.ejianc.business.base.service.ISupplierbankService;
import com.ejianc.business.base.service.ISupplierinfoService;
import com.ejianc.business.base.vo.ShippersLinkerVO;
import com.ejianc.business.base.vo.SupplierbankVO;
import com.ejianc.business.base.vo.SupplierlinkerVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.ExcelReader;
import com.ejianc.framework.core.util.FileUtils;
import com.ejianc.framework.core.util.ImportTemplate;
import com.ejianc.support.idworker.util.IdWorker;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.*;

/**
 * 运输商联系人导入
 */
@Controller
@RequestMapping("shipperLinkerExport")
public class ExcelShipperLinkerController implements Serializable {
    private static final long serialVersionUID = 1L;
    @Autowired
    private IShippersLinkerService service;
    @Autowired
    private IShippersService shippersService;
    @Autowired
    private IBillCodeApi billCodeApi;

    private static final String BILL_CODE = "shippers-linker";//此处需要根据实际修改
    /**
     * 导入模板下载
     *
     * @param request
     * @param response
     */
    @RequestMapping(value = "/downloadShipperLinker")
    @ResponseBody
    public void downloadSupplybank(HttpServletRequest request, HttpServletResponse response) {
        ImportTemplate.initialize(response);
        ImportTemplate.templetdownload(request, "shipperlinker-import.xlsx", "运输商联系人信息导入模板");
    }
    /**
     * excel导入
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/excelImportShipperlinker", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<Object> excelImportShipperlinker(HttpServletRequest request, HttpServletResponse response){
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        List<ShippersLinkerVO> successList = new ArrayList<>();
        List<ShippersLinkerVO> errorList = new ArrayList<>();
        HashMap<String, String> map = new HashMap<>();
        boolean isFailed = false;
        MultipartFile mf = null;
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            mf = entity.getValue();
            String originalFileName = mf.getOriginalFilename();
            String extName = null;
            originalFileName = originalFileName.replaceAll("\\/|\\/|\\||:|\\?|\\*|\"|<|>|\\p{Cntrl}", "_");
            originalFileName.replaceAll("00.", "");
            extName = FileUtils.getFileExt(originalFileName, false);
            if (!"xls".equals(extName) && !"xlsx".equals(extName)) {
                isFailed = true;
                break;
            }
        }
        if (isFailed) {
            return CommonResponse.error("文件格式不合法");
        } else {
            List<List<String>> result = ExcelReader.readExcel(mf);
            if ( result.size() > 0) {
                for (int i = 1; i < result.size(); i++) {
                    List<String> data = result.get(i);
                    ShippersLinkerVO VO =new ShippersLinkerVO();
                    VO.setId(IdWorker.getId());
                    VO.setName(StringUtils.isNotBlank(data.get(0)) ? data.get(0) : null);
                    VO.setShipperManageName(StringUtils.isNotBlank(data.get(1)) ? data.get(1) : null);
                    VO.setLinkerName(StringUtils.isNotBlank(data.get(2)) ? data.get(2) : null);
                    VO.setLinkerPhone(StringUtils.isNotBlank(data.get(3)) ? data.get(3) : null);
                    VO.setTenantId(InvocationInfoProxy.getTenantid());
                    VO.setOrgId(InvocationInfoProxy.getOrgId());
                    VO.setCreateUserCode(InvocationInfoProxy.getUsercode());
                    VO.setCreateTime(new Date());
                    if (StringUtils.isEmpty(data.get(0)) || data.get(0) == null) {
                        VO.setErrorMsg("'运输商联系人名称'不能为空！");
                        errorList.add(VO);
                        continue;
                    }
                    if (StringUtils.isEmpty(data.get(1)) || data.get(1) == null) {
                        VO.setErrorMsg("'运输商名称'不能为空！");
                        errorList.add(VO);
                        continue;
                    }else{
                        QueryWrapper query=new QueryWrapper();
                        query.eq("name",data.get(1));
                        query.eq("org_id",InvocationInfoProxy.getOrgId());
                        ShippersEntity entity = shippersService.getOne(query);
                        if (entity!=null&&(entity.getId()!=null|| entity.getId() != 0)){
                            VO.setShipperMid(entity.getId());
                        }else {
                            VO.setErrorMsg("运输商名称库未查找到运输商名称，请检查！");
                            errorList.add(VO);
                            continue;
                        }
                    }
                    if (StringUtils.isEmpty(data.get(2)) || data.get(2) == null) {
                        VO.setErrorMsg("'联系人名称'不能为空！");
                        errorList.add(VO);
                        continue;
                    }
                    if (StringUtils.isEmpty(data.get(3)) || data.get(3) == null) {
                        VO.setErrorMsg("'手机号'不能为空！");
                        errorList.add(VO);
                        continue;
                    }
                    successList.add(VO);
                }
                if (errorList.size()==0) {
                    List<ShippersLinkerEntity> shippersLinkerEntities = BeanMapper.mapList(successList, ShippersLinkerEntity.class);
                    for (ShippersLinkerEntity entity : shippersLinkerEntities) {
                        ShippersLinkerVO VO = BeanMapper.map(entity, ShippersLinkerVO.class);
                        BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(),VO);
                        CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
                        if(billCode.isSuccess()) {
                            entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                        }
                    }
                    service.saveBatch(shippersLinkerEntities, successList.size());
                }
            }
        }
        JSONObject json = new JSONObject();
        json.put("successNum", successList.size());
        json.put("successList", successList);
        json.put("errorList", errorList);
        json.put("errorNum", errorList.size());
        return CommonResponse.success(json);
    }
}
